@@ -6,6 +6,8 @@
 
 #include <QMenu>
 
+class QQuickItem;
+
 /**
  * This class only exists to make QMenu more usable with Qt Quick
  */
@@ -27,6 +29,11 @@ public:
      */
     Q_INVOKABLE void popup(const QPointF &globalPos);
 
+    /**
+     * Popup on the specified item
+     */
+    Q_INVOKABLE virtual void popup(QQuickItem *item);
+
 Q_SIGNALS:
     void visibleChanged();
 };
