@@ -5,6 +5,9 @@
 
 #include "Platform.h"
 
-Platform::Platform(QObject *parent) :
-    QObject(parent)
-{}
+Platform::Platform(QObject *parent)
+    : QObject(parent)
+{
+}
+
+#include "moc_Platform.cpp"
